package VMOMI::ClusterDasConfigInfoVmMonitoringState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
